#
# spec file for package python-FontTools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-FontTools
Version:        3.24.1
Release:        2.11
License:        MIT and OFL-1.1
Summary:        Suite of Tools and Libraries for Manipulating Fonts
Url:            http://github.com/fonttools/fonttools
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/F/FontTools/fonttools-%{version}.zip
BuildRequires:  %{python_module devel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%if %{with test}
BuildRequires:  %{python_module brotlipy}
BuildRequires:  %{python_module munkres}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest >= 3.0}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module reportlab}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tox}
BuildRequires:  %{python_module setuptools}
%endif
Recommends:     python-brotlipy
Recommends:     python-munkres
Recommends:     python-numpy
Recommends:     python-reportlab
Recommends:     python-scipy
Recommends:     python-sympy
BuildArch:      noarch
%ifpython3      
Conflicts:      fonttools < %{version}
Recommends:     fonttools = %{version}
%endif

%python_subpackages

%description
FontTools is a suite of tools and libraries for manipulating fonts
written in Python.

It currently reads and writes TrueType font files, reads PostScript
Type 1 fonts, and more. It contains two command line programs to
convert TrueType fonts to an XML based format (called TTX) and back.

%package     -n fonttools
Summary:        Suite of Tools and Libraries for Manipulating Fonts
Group:          Productivity/Graphics/Vector Editors
Requires:       python3-FontTools

%description -n fonttools
FontTools is a suite of tools and libraries for manipulating fonts
written in Python.

It currently reads and writes TrueType font files, reads PostScript
Type 1 fonts, and more. It contains two command line programs to
convert TrueType fonts to an XML based format (called TTX) and back.

%prep
%setup -q -n fonttools-%{version}
# Remove shebang
sed -i -e '/^#!\//, 1d' Lib/fontTools/mtiLib/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export LANG=en_US.UTF-8
%python_exec setup.py test
%endif

%files %{python_files}
%doc LICENSE LICENSE.external README.rst NEWS.rst
%{python_sitelib}/*

%files -n fonttools
%doc LICENSE LICENSE.external README.rst NEWS.rst
%{_bindir}/fonttools
%{_bindir}/pyftinspect
%{_bindir}/pyftmerge
%{_bindir}/pyftsubset
%{_bindir}/ttx
%{_mandir}/man1/ttx.1%{ext_man}

%changelog
* Thu Mar  8 2018 toddrme2178@gmail.com
- Update to version 3.24.1
  * [varLib] Don’t remap the same DeviceTable twice in VarStore
    optimizer (#1206).
  * [varLib] Add --disable-iup option to fonttools varLib script,
    and a optimize=True keyword argument to varLib.build function,
    to optionally disable IUP optimization while building varfonts.
  * [ttCollection] Fixed issue while decompiling ttc with python3
    (#1207).
- Update to version 3.24.0
  * [ttGlyphPen] Decompose composite glyphs if any components’
    transform is too large to fit a F2Dot14 value, or clamp
    transform values that are (almost) equal to +2.0 to make them
    fit and avoid decomposing (#1200, #1204, #1205).
  * [ttx] Added new -g option to dump glyphs from the glyf table
    splitted as individual ttx files (#153, #1035, #1132, #1202).
  * Copied ufoLib.filenames module to fontTools.misc.filenames,
    used for the ttx split-glyphs option (#1202).
  * [feaLib] Added support for cvParameters blocks in Character
    Variant feautures cv01-cv99 (#860, #1169).
  * [Snippets] Added checksum.py script to generate/check SHA1
    hash of ttx files (#1197).
  * [varLib.mutator] Fixed issue while instantiating some variable
    fonts whereby the horizontal advance width computed from gvar
    phantom points could turn up to be negative (#1198).
  * [varLib/subset] Fixed issue with subsetting GPOS variation
    data not picking up ValueRecord Device objects (54fd71f).
  * [feaLib/voltLib] In all AST elements, the location is no
    longer a required positional argument, but an optional
    kewyord argument (defaults to None). This will make it easier
    to construct feature AST from code (#1201).
- Update to version 3.23.0
  * [designspaceLib] Added an optional lib element to the
    designspace as a whole, as well as to the instance elements,
    to store arbitrary data in a property list dictionary, similar
    to the UFO’s lib. Added an optional font attribute to the
    SourceDescriptor, to allow operating on in-memory font objects
    (#1175).
  * [cffLib] Fixed issue with lazy-loading of attributes when
    attempting to set the CFF TopDict.Encoding (#1177, #1187).
  * [ttx] Fixed regression introduced in 3.22.0 that affected
    the split tables -s option (#1188).
  * [feaLib] Added IncludedFeaNotFound custom exception subclass,
    raised when an included feature file cannot be found (#1186).
  * [otTables] Changed VarIdxMap to use glyph names internally
    instead of glyph indexes. The old ttx dumps of HVAR/VVAR
    tables that contain indexes can still be imported
    (21cbab8, 38a0ffb).
  * [varLib] Implemented VarStore optimizer (#1184).
  * [subset] Implemented pruning of GDEF VarStore, HVAR and
    MVAR (#1179).
  * [sfnt] Restore backward compatiblity with numFonts attribute
    of SFNTReader object (#1181).
  * [merge] Initial support for merging LangSysRecords (#1180).
  * [ttCollection] don’t seek(0) when writing to possibly
    unseekable strems.
  * [subset] Keep all --name-IDs from 0 to 6 by default
    (#1170, #605, #114).
  * [cffLib] Added width module to calculate optimal CFF default
    and nominal glyph widths.
  * [varLib] Don’t fail if STAT already in the master fonts
    (#1166).
- Fix conflict with old single-package version
* Mon Feb 26 2018 toddrme2178@gmail.com
- Fix building on tumbleweed
* Tue Feb 20 2018 toddrme2178@gmail.com
- Initial version
